
# Slot: has familial relationships




URI: [ks:has_familial_relationships](https://w3id.org/linkml/tests/kitchen_sink/has_familial_relationships)


## Domain and Range

None &#8594;  <sub>0..\*</sub> [FamilialRelationship](FamilialRelationship.md)

## Parents


## Children


## Used by

 * [Person](Person.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **In Subsets:** | | subset B |

